@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2015-2016 Montel Laurent <montel@kde.org>
+  Copyright (c) 2015-2018 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -21,13 +21,12 @@
 #include <QPrintPreviewDialog>
 #include "pimcommon_export.h"
 
-namespace PimCommon
-{
+namespace PimCommon {
 class PIMCOMMON_EXPORT KPimPrintPreviewDialog : public QPrintPreviewDialog
 {
 public:
-    explicit KPimPrintPreviewDialog(QWidget *parent = Q_NULLPTR);
-    explicit KPimPrintPreviewDialog(QPrinter *printer, QWidget *parent = 0);
+    explicit KPimPrintPreviewDialog(QWidget *parent = nullptr);
+    explicit KPimPrintPreviewDialog(QPrinter *printer, QWidget *parent = nullptr);
     ~KPimPrintPreviewDialog();
 private:
     void readConfig();
